@@ -1085,11 +1085,7 @@ show_dialog:
     g_free (markup);
     gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
     gtk_label_set_max_width_chars (GTK_LABEL (label), 50);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 
     label = gtk_label_new (NULL);
@@ -1100,11 +1096,7 @@ show_dialog:
     g_free (markup);
     gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
     gtk_label_set_max_width_chars (GTK_LABEL (label), 50);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 
     data = g_new0 (AutorunDialogData, 1);
