@@ -133,20 +133,11 @@ caja_window_init (CajaWindow *window)
     GtkWidget *menu;
     GtkWidget *statusbar;
 
-#if GTK_CHECK_VERSION (3, 20, 0)
     static const gchar css_custom[] =
       "#caja-extra-view-widget {"
       "  background-color: " EXTRA_VIEW_WIDGETS_BACKGROUND ";"
       "}";
-#else
-    static const gchar css_custom[] =
-      "#statusbar-no-border {"
-      "  -GtkStatusbar-shadow-type: none;"
-      "}"
-      "#caja-extra-view-widget {"
-      "  background-color: " EXTRA_VIEW_WIDGETS_BACKGROUND ";"
-      "}";
-#endif
+
     GError *error = NULL;
     GtkCssProvider *provider = gtk_css_provider_new ();
     gtk_css_provider_load_from_data (provider, css_custom, -1, &error);
